@@ -89,7 +89,10 @@ class SparseArray:
                         'indices must be integers, slices, np.ndarray, Ellipsis, or NoneType - not {}'.format(
                             type(item)))
 
-            return self.__getitem__(items[0])[items[1:]]
+            new_items = list(items)
+            new_items[0] = slice(None, None, None)
+
+            return self.__getitem__(items[0])[tuple(new_items)]
 
         else:
             raise TypeError(
